pub type Text<'input> = TextVec<PosStr<'input>>;Expand description
Chosen so that the referenced parts of an input string are zero-copy, and so
that char and byte positions are tracked (relative to the input &str),
and so that, when chunks are broken around escape characters, a simple Vec
is used to logically concatenate them.
This Text type is a TextVec of PosStr chunks.
Aliased Type
pub struct Text<'input>(/* private fields */);